@@ -3,7 +3,8 @@ import subprocess as sp
 from typing import (
     Union, Tuple
 )
-from superprocessor.util import (
+
+from superprocessor.superprocessor.util import (
     set_logs, set_defaults, log,
 )
 
@@ -14,7 +15,7 @@ Author: Samoto
 """
 
 
-def cmd(* args: str, ** kwargs) -> Tuple[str, Union[str, None]]:
+def cmd(* args: str, ** kwargs) -> Tuple[str, Union[str, None], int]:
     """
     :param args: list of strings --
         to be concatenated into stmt
@@ -48,4 +49,8 @@ def cmd(* args: str, ** kwargs) -> Tuple[str, Union[str, None]]:
 
     log(f'response: {resp}')
 
-    return resp.stdout, resp.stderr or None
+    return (
+        resp.stdout,
+        resp.stderr or None,
+        resp.returncode,
+    )
